@@ -105,9 +105,10 @@ mutate..tidytable <- function(.df, ..., .by = NULL,
     one_dot <- length(dots) == 1
 
     if (!one_dot) {
-      across_bool <- map_lgl(dots[-1], quo_is_call, "across.")
-
-      if (any(across_bool)) {
+      is_across <- map_lgl(dots[-1], quo_is_call, c("across.", "across"))
+      if (any(is_across)) {
+        # tidyselect helpers will miss columns made before an across call
+        # that is not in the first position
         abort("across() can only be used in the first position of mutate()
               when `.by` is used.")
       }
@@ -119,9 +120,9 @@ mutate..tidytable <- function(.df, ..., .by = NULL,
 
     # Check for NULL inputs so columns can be deleted
     # Only delete if the NULL is the last call
-    null_bool <- map_lgl(dots, is_null)
+    is_null <- vec_detect_missing(dots)
     is_last <- !duplicated(names(dots), fromLast = TRUE)
-    needs_removal <- null_bool & is_last
+    needs_removal <- is_null & is_last
     any_null <- any(needs_removal)
 
     if (any_null) {
@@ -237,7 +238,7 @@ sequential_check <- function(dots) {
 
   used_vars <- unique(unlist(map(dots[-1], extract_used)))
 
-  any(dots_names %in% used_vars) || any(vec_duplicate_detect(dots_names))
+  any(dots_names %in% used_vars) || vec_duplicate_any(dots_names)
 }
 
 get_keep_vars <- function(df, dots, .by, .keep = "all") {
