@@ -19,22 +19,29 @@
 #' )
 #'
 #' df %>%
-#'   select.(x1, y)
+#'   select(x1, y)
 #'
 #' df %>%
-#'   select.(x1:y)
+#'   select(x1:y)
 #'
 #' df %>%
-#'   select.(-y, -z)
+#'   select(-y, -z)
 #'
 #' df %>%
-#'   select.(starts_with("x"), z)
+#'   select(starts_with("x"), z)
 #'
 #' df %>%
-#'   select.(where(is.character), x1)
+#'   select(where(is.character), x1)
 #'
 #' df %>%
-#'   select.(new = x1, y)
+#'   select(new = x1, y)
+select <- function(.df, ...) {
+  select.(.df, ...)
+}
+
+#' @export
+#' @keywords internal
+#' @inherit select
 select. <- function(.df, ...) {
   UseMethod("select.")
 }
@@ -50,8 +57,17 @@ select..tidytable <- function(.df, ...) {
   tidytable_restore(out, .df)
 }
 
+#' @export
+select..grouped_tt <- function(.df, ...) {
+  .by <- group_vars(.df)
+  out <- ungroup(.df)
+  out <- select(out, ..., all_of(.by))
+  group_by(out, all_of(.by))
+}
+
 #' @export
 select..data.frame <- function(.df, ...) {
   .df <- as_tidytable(.df)
-  select.(.df, ...)
+  select(.df, ...)
 }
+
