@@ -30,7 +30,7 @@ tidytable_fns <- c(
   "filter.", "filter",
   "mutate.", "mutate",
   "slice.", "slice",
-  "summarise.", "summarise.", "summarize.", "summarize"
+  "summarise.", "summarise", "summarize.", "summarize"
 )
 
 call_fns <- c(
@@ -58,8 +58,8 @@ prep_expr_call <- function(x, data, .by = NULL, j = FALSE, dt_env = caller_env()
     x[[1]] <- sym("-")
     x[[2]] <- prep_expr(x[[2]], data, {{ .by }}, j, dt_env, is_top_across)
     x
-  } else if (is_call(x, c("row_number.", "row_number", "cur_group_rows.", "cur_group_rows"))) {
-    quote(1:.N)
+  } else if (is_call(x, c("row_number.", "row_number", "cur_group_rows.", "cur_group_rows"), 0)) {
+    quote(seq_len(.N))
   } else if (is_call(x, c("cur_group_id.", "cur_group_id"))) {
     quote(.GRP)
   } else if (is_call(x, c("cur_data.", "cur_data"))) {
